@@ -7,7 +7,7 @@ RDF::Trine::Node::Nil - RDF Node class for the nil node
 
 =head1 VERSION
 
-This document describes RDF::Trine::Node::Nil version 0.136
+This document describes RDF::Trine::Node::Nil version 0.137
 
 =cut
 
@@ -27,7 +27,7 @@ use Carp qw(carp croak confess);
 my $NIL_NODE;
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.136';
+	$VERSION	= '0.137';
 }
 
 ######################################################################
@@ -82,6 +82,18 @@ sub sse {
 	return '(nil)';
 }
 
+=item C<< as_ntriples >>
+
+Returns the N-Triples serialization of the nil node's IRI
+<tag:gwilliams@cpan.org,2010-01-01:RT:NIL>.
+
+=cut
+
+sub as_ntriples {
+	my $self	= shift;
+	return sprintf('<%s>', &RDF::Trine::NIL_GRAPH());
+}
+
 =item C<< type >>
 
 Returns the type string of this node.
