@@ -4,7 +4,7 @@ RDF::Trine::Store::Hexastore - RDF store implemented with the hexastore index
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::Hexastore version 0.136
+This document describes RDF::Trine::Store::Hexastore version 0.137
 
 =head1 SYNOPSIS
 
@@ -43,7 +43,7 @@ use constant OTHERNODES	=> {
 
 our $VERSION;
 BEGIN {
-	$VERSION	= "0.136";
+	$VERSION	= "0.137";
 	my $class	= __PACKAGE__;
 	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 }
@@ -106,13 +106,8 @@ The following example initializes a Hexastore store based on a local file and a
 
 sub new {
 	my $class	= shift;
-	my $self	= bless({
-		data		=> $class->_new_index_page,
-		node2id		=> {},
-		id2node		=> {},
-		next_id		=> 1,
-		size		=> 0,
-	}, $class);
+	my $self        = bless({}, $class);
+	$self->nuke; # nuke resets the store, thus doing the same thing as init should do
 	return $self;
 }
 
@@ -590,12 +585,24 @@ sub remove_statement {
 
 Removes the specified C<$statement> from the underlying model.
 
+=item C<< nuke >>
+
+Permanently removes all the data in the store.
+
 =cut
 
-sub remove_statements {
-	die;
+sub nuke {
+    my $self = shift;
+    $self->{data} = $self->_new_index_page;
+    $self->{node2id} = {};
+    $self->{id2node} = {};
+    $self->{next_id} = 1;
+    $self->{size} = 0;
+    return $self;
 }
 
+
+
 =item C<< count_statements ($subject, $predicate, $object) >>
 
 Returns a count of all the statements matching the specified subject,
